@@ -13,9 +13,20 @@ sh_key::sh_key(QWidget *parent) :
     this->setAlignment(Qt::AlignCenter);
 }
 
+
+
 keys::keys(QWidget *parent) :
         QWidget(parent)
 {
+
+ ks=QStringList()<<tr("Left")<<tr("Right")<<tr("Up")
+                                <<tr("Down")<<tr("o")<<tr("x")<<tr("triangle")
+                                <<tr("square")<<tr("Select")<<tr("Start")
+                                <<tr("L1")<<tr("R1")<<tr("L2")<<tr("R2")<<tr("Quit")
+                                <<tr("Up+Left")<<tr("Up+Right")
+                                <<tr("Down+Left")<<tr("Down+Right")
+                                <<tr("Save")<<tr("Load")<<tr("slot+")<<tr("slot-");
+
 this->setWindowFlags(this->windowFlags() | Qt::Window);
 this->setAttribute(Qt::WA_Maemo5StackedWindow);
 QScrollArea *area=new QScrollArea(this);
@@ -30,13 +41,7 @@ area->show();
 grid->setHorizontalSpacing(25);
 grid->setVerticalSpacing(25);
 
-QStringList ks=QStringList()<<tr("Left")<<tr("Right")<<tr("Up")
-                            <<tr("Down")<<tr("o")<<tr("x")<<tr("triangle")
-                            <<tr("square")<<tr("Select")<<tr("Start")
-                            <<tr("L1")<<tr("R1")<<tr("L2")<<tr("R2")<<tr("Quit")
-                            <<tr("Up+Left")<<tr("Up+Right")
-                            <<tr("Down+Left")<<tr("Down+Right")
-                            <<tr("Save")<<tr("Load");
+
 
 
 // load current
@@ -50,7 +55,7 @@ if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
 
 int o=0;
      QTextStream in(&file);
-     while ((o<21)) {
+     while ((o<ks.count())) {
          QString line="0";
          if (!in.atEnd())
          line = in.readLine();
@@ -89,7 +94,7 @@ void keys::hideEvent(QHideEvent *){
 
 void keys::save(){
 QString sv="";
-for (int i=0;i<=20;i++)
+for (int i=0;i<ks.count();i++)
     sv=sv+QString("%1\n").arg(nkey[i]->text());
 
 QFile file("/opt/psx4m/keys");
