@@ -79,7 +79,7 @@ if (st.count()>1){
 
 QProcess *myProcess = new QProcess();
 QStringList args=current_config;
-args<<roms.value(ui->listWidget->currentRow());
+args<<roms.value(ui->listWidget->currentRow())<<"-save_name"<<(ui->listWidget->currentItem()->text());;
 qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/"+current_core)
         .arg(args.join(" ")).toAscii());
 myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/");
