@@ -61,6 +61,12 @@ void options::load_cfg(){
     configs<<"accel";
     configs<<"cdda" <<    "xa" <<    "rcnt"<<    "sio"<<    "spuirq"<<    "vsync";
     configs<<"fsaa"<<"pcsx-fullscreen";
+    configs<<"pcsx-fps"<<"pcsx-cpu"<<"pcsx-nofl";
+
+    ui->comboBox_5->setCurrentIndex(0);
+    ui->checkBox_4->setChecked(false);
+    ui->checkBox_18->setChecked(false);
+    ui->checkBox_19->setChecked(false);
 
     if (QFile::exists(path)){
 
@@ -110,7 +116,8 @@ if (value=="")value="scph1001.bin";
                       if (value=="1")ui->checkBox_3->setChecked(true);else ui->checkBox_3->setChecked(false);
                       break;
                  case 10:// pcsx-hwa
-                      if (value=="1")ui->checkBox_4->setChecked(true);else ui->checkBox_4->setChecked(false);
+                     if (ui->comboBox_5->findText(value)!=1)
+                         ui->comboBox_5->setCurrentIndex(ui->comboBox_5->findText(value));
                       break;
                  case 11:// pcsx-bios
                       if (value=="1")ui->checkBox_5->setChecked(true);else ui->checkBox_5->setChecked(false);
@@ -146,6 +153,15 @@ if (value=="")value="scph1001.bin";
                  case 21:
                       if (value=="1")ui->checkBox_17->setChecked(true);else ui->checkBox_17->setChecked(false);
                       break;
+                 case 22:
+                      if (value=="1")ui->checkBox_4->setChecked(true);else ui->checkBox_4->setChecked(false);
+                      break;
+                 case 23:
+                      if (value=="1")ui->checkBox_18->setChecked(true);else ui->checkBox_18->setChecked(false);
+                      break;
+                 case 24:
+                      if (value=="1")ui->checkBox_19->setChecked(true);else ui->checkBox_19->setChecked(false);
+                      break;
                  default:
                       qDebug(QString("Undefined setting:%1 = %2").arg(line.at(0)).arg(value).toAscii());
                       break;
@@ -175,12 +191,16 @@ void options::createCfg(){
     if (ui->checkBox_14->isChecked())current_config<<"-rcnt";
     if (ui->checkBox_15->isChecked())current_config<<"-vsync";
 
+
+
     if (ui->radioButton_2->isChecked())
     {
         current_core="pcsx";
 
         if (ui->checkBox_3->isChecked())current_config<<"-sputhreaded";
-        if (ui->checkBox_4->isChecked())current_config<<"-gles";
+        if (ui->comboBox_5->currentText()=="oldgpu")current_config<<"-oldgpu";
+else if (ui->comboBox_5->currentText()=="gpu-gles")current_config<<"-gles";
+else if (ui->comboBox_5->currentText()=="gpu_unai")current_config<<"-unai";
 
         if (ui->checkBox_5->isChecked())
             if (!ui->comboBox_4->currentText().isEmpty() && !bios_path.isEmpty())
@@ -188,6 +208,11 @@ void options::createCfg(){
         if (ui->comboBox_3->currentIndex()>0)
         current_config<<"-frameskip"<<QString("%1").arg(ui->comboBox_3->currentIndex());
         if (ui->checkBox_17->isChecked())current_config<<"-fullscreen";
+        if (ui->checkBox_4->isChecked())current_config<<"-fps";
+        if (ui->checkBox_18->isChecked())current_config<<"-cpu";
+        if (ui->checkBox_19->isChecked())current_config<<"-nofl";
+
+
         current_config<<"-cdfile";
 
     }
@@ -247,7 +272,10 @@ void options::save_cfg(){
                    "spuirq=%19\n" \
                    "vsync=%20\n" \
                    "fsaa=%21\n" \
-                   "pcsx-fullscreen=%22\n" )
+                   "pcsx-fullscreen=%22\n"\
+                   "pcsx-fps=%23\n" \
+                "pcsx-cpu=%24\n" \
+                "pcsx-nofl=%25\n")
             .arg(ui->radioButton_2->isChecked()?"1":"0")
             .arg(ui->checkBox->isChecked()?"1":"0")
             .arg(ui->comboBox_4->currentText())
@@ -258,7 +286,7 @@ void options::save_cfg(){
 .arg(ui->checkBox_7->isChecked()?"1":"0")
 .arg(ui->checkBox_8->isChecked()?"1":"0")
             .arg(ui->checkBox_3->isChecked()?"1":"0")
-            .arg(ui->checkBox_4->isChecked()?"1":"0")
+            .arg(ui->comboBox_5->currentText())
             .arg(ui->checkBox_5->isChecked()?"1":"0")
             .arg(ui->comboBox_3->currentText())
 .arg(ui->checkBox_9->isChecked()?"1":"0")
@@ -270,7 +298,9 @@ void options::save_cfg(){
 .arg(ui->checkBox_15->isChecked()?"1":"0")
         .arg(ui->checkBox_16->isChecked()?"1":"0")
         .arg(ui->checkBox_17->isChecked()?"1":"0")
-
+            .arg(ui->checkBox_5->isChecked()?"1":"0")
+            .arg(ui->checkBox_18->isChecked()?"1":"0")
+            .arg(ui->checkBox_19->isChecked()?"1":"0")
 ;
 
     QFile file(path);
